# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#

from __future__ import \
    absolute_import, division, print_function, unicode_literals


from htf.io.boards import BaseBoard, OutputPin, InputPin
import logging
logger = logging.getLogger(__name__)
# logging.basicConfig(level=logging.DEBUG)


class ArduinoNano(BaseBoard):
    BOARDNAME = b"Arduino Nano"
    SETTLE_TIME = 1.0

    def __init__(self, port, timeout=0.5):
        """
        Initialize an ArduinoNano.

        Args:
            port (str): the name of the serial connection
            timeout=0.5 (float): the time-out in seconds
        """
        super(ArduinoNano, self).__init__(port=port, timeout=timeout)

        # Digital Outputs
        self.digital_output2 = self.do2 = OutputPin(2, self.digital_output)
        self.digital_output3 = self.do3 = OutputPin(3, self.digital_output)
        self.digital_output4 = self.do4 = OutputPin(4, self.digital_output)
        self.digital_output5 = self.do5 = OutputPin(5, self.digital_output)
        self.digital_output6 = self.do6 = OutputPin(6, self.digital_output)
        self.digital_output7 = self.do7 = OutputPin(7, self.digital_output)
        self.digital_output8 = self.do8 = OutputPin(8, self.digital_output)
        self.digital_output9 = self.do9 = OutputPin(9, self.digital_output)
        self.digital_output10 = self.do10 = OutputPin(10, self.digital_output)
        self.digital_output11 = self.do11 = OutputPin(11, self.digital_output)
        self.digital_output12 = self.do12 = OutputPin(12, self.digital_output)
        self.digital_output13 = self.do13 = OutputPin(13, self.digital_output)

        # Digital Inputs
        self.digital_input2 = self.di2 = InputPin(2, self.digital_input)
        self.digital_input3 = self.di3 = InputPin(3, self.digital_input)
        self.digital_input4 = self.di4 = InputPin(4, self.digital_input)
        self.digital_input5 = self.di5 = InputPin(5, self.digital_input)
        self.digital_input6 = self.di6 = InputPin(6, self.digital_input)
        self.digital_input7 = self.di7 = InputPin(7, self.digital_input)
        self.digital_input8 = self.di8 = InputPin(8, self.digital_input)
        self.digital_input9 = self.di9 = InputPin(9, self.digital_input)
        self.digital_input10 = self.di10 = InputPin(10, self.digital_input)
        self.digital_input11 = self.di11 = InputPin(11, self.digital_input)
        self.digital_input12 = self.di12 = InputPin(12, self.digital_input)
        self.digital_input13 = self.di13 = InputPin(13, self.digital_input)

        # Digital Inputs with internal Pullup
        self.digital_input_pullup2 = self.dip2 = InputPin(2, self.digital_input_pullup)
        self.digital_input_pullup3 = self.dip3 = InputPin(3, self.digital_input_pullup)
        self.digital_input_pullup4 = self.dip4 = InputPin(4, self.digital_input_pullup)
        self.digital_input_pullup5 = self.dip5 = InputPin(5, self.digital_input_pullup)
        self.digital_input_pullup6 = self.dip6 = InputPin(6, self.digital_input_pullup)
        self.digital_input_pullup7 = self.dip7 = InputPin(7, self.digital_input_pullup)
        self.digital_input_pullup8 = self.dip8 = InputPin(8, self.digital_input_pullup)
        self.digital_input_pullup9 = self.dip9 = InputPin(9, self.digital_input_pullup)
        self.digital_input_pullup10 = self.dip10 = InputPin(10, self.digital_input_pullup)
        self.digital_input_pullup11 = self.dip11 = InputPin(11, self.digital_input_pullup)
        self.digital_input_pullup12 = self.dip12 = InputPin(12, self.digital_input_pullup)
        self.digital_input_pullup13 = self.dip13 = InputPin(13, self.digital_input_pullup)

        # Analog Outputs: 3, 5, 6, 9, 10, and 11
        self.pwm3 = self.analog_output3 = self.ao3 = OutputPin(3, self.pwm)
        self.pwm5 = self.analog_output5 = self.ao5 = OutputPin(5, self.pwm)
        self.pwm6 = self.analog_output6 = self.ao6 = OutputPin(6, self.pwm)
        self.pwm9 = self.analog_output9 = self.ao9 = OutputPin(9, self.pwm)
        self.pwm10 = self.analog_output10 = self.ao10 = OutputPin(10, self.pwm)
        self.pwm11 = self.analog_output11 = self.ao11 = OutputPin(11, self.pwm)

        # Analog Inputs
        self.analog_input0 = self.ai0 = InputPin(0, self.analog_input)
        self.analog_input1 = self.ai1 = InputPin(1, self.analog_input)
        self.analog_input2 = self.ai2 = InputPin(2, self.analog_input)
        self.analog_input3 = self.ai3 = InputPin(3, self.analog_input)
        self.analog_input4 = self.ai4 = InputPin(4, self.analog_input)
        self.analog_input5 = self.ai5 = InputPin(5, self.analog_input)
        self.analog_input6 = self.ai6 = InputPin(6, self.analog_input)
        self.analog_input7 = self.ai7 = InputPin(7, self.analog_input)


class ArduinoLeonardo(BaseBoard):
    BOARDNAME = b"Arduino Leonardo"
    SETTLE_TIME = 1.0

    def __init__(self, port, timeout=0.5):
        """
        Initialize an ArduinoLeonardo.

        Args:
            port (str): the name of the serial connection
            timeout=0.5 (float): the time-out in seconds
        """
        super(ArduinoLeonardo, self).__init__(port=port, timeout=timeout)

        # Digital Outputs
        self.digital_output0 = self.do0 = OutputPin(0, self.digital_output)
        self.digital_output1 = self.do1 = OutputPin(1, self.digital_output)
        self.digital_output2 = self.do2 = OutputPin(2, self.digital_output)
        self.digital_output3 = self.do3 = OutputPin(3, self.digital_output)
        self.digital_output4 = self.do4 = OutputPin(4, self.digital_output)
        self.digital_output5 = self.do5 = OutputPin(5, self.digital_output)
        self.digital_output6 = self.do6 = OutputPin(6, self.digital_output)
        self.digital_output7 = self.do7 = OutputPin(7, self.digital_output)
        self.digital_output8 = self.do8 = OutputPin(8, self.digital_output)
        self.digital_output9 = self.do9 = OutputPin(9, self.digital_output)
        self.digital_output10 = self.do10 = OutputPin(10, self.digital_output)
        self.digital_output11 = self.do11 = OutputPin(11, self.digital_output)
        self.digital_output12 = self.do12 = OutputPin(12, self.digital_output)
        self.digital_output13 = self.do13 = OutputPin(13, self.digital_output)

        # Digital Inputs
        self.digital_input0 = self.di0 = InputPin(0, self.digital_input)
        self.digital_input1 = self.di1 = InputPin(1, self.digital_input)
        self.digital_input2 = self.di2 = InputPin(2, self.digital_input)
        self.digital_input3 = self.di3 = InputPin(3, self.digital_input)
        self.digital_input4 = self.di4 = InputPin(4, self.digital_input)
        self.digital_input5 = self.di5 = InputPin(5, self.digital_input)
        self.digital_input6 = self.di6 = InputPin(6, self.digital_input)
        self.digital_input7 = self.di7 = InputPin(7, self.digital_input)
        self.digital_input8 = self.di8 = InputPin(8, self.digital_input)
        self.digital_input9 = self.di9 = InputPin(9, self.digital_input)
        self.digital_input10 = self.di10 = InputPin(10, self.digital_input)
        self.digital_input11 = self.di11 = InputPin(11, self.digital_input)
        self.digital_input12 = self.di12 = InputPin(12, self.digital_input)
        self.digital_input13 = self.di13 = InputPin(13, self.digital_input)

        # Digital Inputs with internal Pullup
        self.digital_input_pullup0 = self.dip0 = InputPin(0, self.digital_input_pullup)
        self.digital_input_pullup1 = self.dip1 = InputPin(1, self.digital_input_pullup)
        self.digital_input_pullup2 = self.dip2 = InputPin(2, self.digital_input_pullup)
        self.digital_input_pullup3 = self.dip3 = InputPin(3, self.digital_input_pullup)
        self.digital_input_pullup4 = self.dip4 = InputPin(4, self.digital_input_pullup)
        self.digital_input_pullup5 = self.dip5 = InputPin(5, self.digital_input_pullup)
        self.digital_input_pullup6 = self.dip6 = InputPin(6, self.digital_input_pullup)
        self.digital_input_pullup7 = self.dip7 = InputPin(7, self.digital_input_pullup)
        self.digital_input_pullup8 = self.dip8 = InputPin(8, self.digital_input_pullup)
        self.digital_input_pullup9 = self.dip9 = InputPin(9, self.digital_input_pullup)
        self.digital_input_pullup10 = self.dip10 = InputPin(10, self.digital_input_pullup)
        self.digital_input_pullup11 = self.dip11 = InputPin(11, self.digital_input_pullup)
        self.digital_input_pullup12 = self.dip12 = InputPin(12, self.digital_input_pullup)
        self.digital_input_pullup13 = self.dip13 = InputPin(13, self.digital_input_pullup)

        # Analog Outputs
        self.pwm3 = self.analog_output3 = self.ao3 = OutputPin(3, self.pwm)
        self.pwm5 = self.analog_output5 = self.ao5 = OutputPin(5, self.pwm)
        self.pwm6 = self.analog_output6 = self.ao6 = OutputPin(6, self.pwm)
        self.pwm9 = self.analog_output9 = self.ao9 = OutputPin(9, self.pwm)
        self.pwm10 = self.analog_output10 = self.ao10 = OutputPin(10, self.pwm)
        self.pwm11 = self.analog_output11 = self.ao11 = OutputPin(11, self.pwm)
        self.pwm13 = self.analog_output13 = self.ao13 = OutputPin(13, self.pwm)

        # Analog Inputs: A0-A5, A6 - A11 (on digital pins 4, 6, 8, 9, 10, and 12).
        self.analog_input0 = self.ai0 = InputPin(0, self.analog_input)
        self.analog_input1 = self.ai1 = InputPin(1, self.analog_input)
        self.analog_input2 = self.ai2 = InputPin(2, self.analog_input)
        self.analog_input3 = self.ai3 = InputPin(3, self.analog_input)
        self.analog_input4 = self.ai4 = InputPin(4, self.analog_input)
        self.analog_input5 = self.ai5 = InputPin(5, self.analog_input)

        self.analog_input6 = self.ai6 = InputPin(6, self.analog_input)
        self.analog_input7 = self.ai7 = InputPin(7, self.analog_input)
        self.analog_input8 = self.ai8 = InputPin(8, self.analog_input)
        self.analog_input9 = self.ai9 = InputPin(9, self.analog_input)
        self.analog_input10 = self.ai10 = InputPin(10, self.analog_input)
        self.analog_input11 = self.ai11 = InputPin(11, self.analog_input)
