# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.communication._ssh import SFTPClient as _SFTPClient
from htf.communication._ssh import SSHClient as _SSHClient


class SFTPClient(_SFTPClient):

    def __init__(self):
        """
        ``SFTPClient`` lets you access files via sftp protocol.
        """
        super(SFTPClient, self).__init__()

    def close(self):
        """
        Close current sftp connection.
        """
        return super(SFTPClient, self).close()

    def connect(self, hostname, username=None, password=None):
        """
        Establish an sftp connection.

        Args:
            hostname (str): the hostname or ip address
            username=None (str): The username to be used. If set to ``None`` the current username is used instead
             of using the ssh keys in your system.
            password=None (str): The password for ``username``. If set to ``None`` the password for ``username``
             or the current username is used.
        """
        return super(SFTPClient, self).connect(hostname=hostname, username=username, password=password)

    def execute(self, *command):
        """
        Execute a command remotely via ssh.

        Args:
            *command (tuple of str): the command to be executed.

        Returns:
            tuple (exitcode, stdout, stderr): a tuple containing exitcode, stdout and stderr of the executed command.
        """
        return super(SFTPClient, self).execute(*command)

    def get(self, remotepath, localpath):
        """
        Copies file identified by ``remotepath`` to ``localpath`` using sftp protocol.

        Args:
            remotepath (str): the remote file to be copied
            localpath (str): the local path where the field is copied to
        """
        return super(SFTPClient, self).get(remotepath=remotepath, localpath=localpath)

    def put(self, localpath, remotepath):
        """
        Copies file identified by ``localpath`` to ``remotepath`` using sftp protocol.

        Args:
            localpath (str): the local path to be copied
            remotepath (str): the remote file where the field is copied to

        Returns:
            SFTPAttributes: the result of os.stat
        """
        return super(SFTPClient, self).put(localpath=localpath, remotepath=remotepath)

    def remove(self, remotepath):
        """
        Removes a file identified by ``remotepath``.

        Args:
            remotepath (str): the path for the file to be removed

        Raises:
            IOError: if the path is not a file
        """
        return super(SFTPClient, self).remove(remotepath=remotepath)

    def rename(self, oldpath, newpath):
        """
        Remotely renames a file or a folder.

        Args:
            oldpath (str): the file or folder to be renamed
            newpath (str): the new file- or foldername

        Raises:
            IOError: if something goes wrong
        """
        return super(SFTPClient, self).rename(oldpath=oldpath, newpath=newpath)

    def unlink(self, remotepath):
        """
        Removes a file identified by ``remotepath``.

        Args:
            remotepath (str): the path for the file to be removed

        Raises:
            IOError: if the path is not a file
        """
        return super(SFTPClient, self).unlink(remotepath=remotepath)



class SSHClient(_SSHClient):

    def __init__(self):
        """
        ``SSHClient`` executes commands remotely using ssh.
        """
        super(SSHClient, self).__init__()

    def close(self):
        """
        Close current ssh connection.
        """
        return super(SSHClient, self).close()

    def connect(self, hostname, username=None, password=None):
        """
        Establish an ssh connection.

        Args:
            hostname (str): the hostname or ip address
            username=None (str): The username to be used. If set to ``None`` the current username is used instead
             of using the ssh keys in your system.
            password=None (str): The password for ``username``. If set to ``None`` the password for ``username``
             or the current username is used.
        """
        return super(SSHClient, self).connect(hostname=hostname, username=username, password=password)

    def execute(self, *command):
        """
        Execute a command remotely via ssh.

        Args:
            *command (tuple of str): the command to be executed.

        Returns:
            tuple (exitcode, stdout, stderr): a tuple containing exitcode, stdout and stderr of the executed command.
        """
        return super(SSHClient, self).execute(*command)

