# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf._filters import filterAnd as _filterAnd
from htf._filters import filterNand as _filterNand
from htf._filters import filterNor as _filterNor
from htf._filters import filterNot as _filterNot
from htf._filters import filterOr as _filterOr
from htf._filters import filterXnor as _filterXnor
from htf._filters import filterXor as _filterXor


def filterAnd(*filters):
    """
    Create a filter that combines all results or values of ``*filters`` using logical and.

    Args:
        *filters (tuple): a tuple of filters.

    Returns:
        callable: a filter that combines all elements in ``*filters`` using logical and.

    Usage::

        >>> filterAnd(filter1, filter2, ..., filterN)
        # If all filters return True, True is returned
    """
    return _filterAnd(*filters)



def filterNand(*filters):
    """
    Create a filter that combines all results or values of ``*filters`` using logical nand.

    Args:
        *filters (tuple): a tuple of filters.

    Returns:
        callable: a filter that combines all elements in ``*filters`` using logical nand.

    Usage::

        >>> filterNand(filter1, filter2, ..., filterN)
        # inverted filterAnd()
    """
    return _filterNand(*filters)



def filterNor(*filters):
    """
    Create a filter that combines all results or values of ``*filters`` using logical nor.

    Args:
        *filters (tuple): a tuple of filters.

    Returns:
        callable: a filter that combines all elements in ``*filters`` using logical nor.

    Usage::

        >>> filterNor(filter1, filter2, ..., filterN)
        # inverted filterOr()
    """
    return _filterNor(*filters)



def filterNot(filterMethod):
    """
    Create a filter that inverts ``filterMethod``'s result or values.

    Args:
        filterMethod (callable): the filter that is inverted.

    Returns:
        callable: a filter that inverts ``filterMethod``.

    Usage:

        >>> filterNot(filter)
        # inverted filter
    """
    return _filterNot(filterMethod=filterMethod)



def filterOr(*filters):
    """
    Create a filter that combines all results or values of ``*filters`` using or-logic.

    Args:
        *filters (tuple): a tuple of filters.

    Returns:
        callable: a filter that conjuncts all elements in ``*filters``.

    Usage::

        >>> filterOr(filter1, filter2, ..., filterN)
        # If at least one filter returns True, True is returned immediately
    """
    return _filterOr(*filters)



def filterXnor(*filters):
    """
    Create a filter that combines all results or values of ``*filters`` using logical xnor.

    Args:
        *filters (tuple): a tuple of filters.

    Returns:
        callable: a filter that combines all elements in ``*filters`` using logical xnor.

    Usage::

        >>> filterXnor(filter1, filter2, ..., filterN)
        # inverted filterXor()
    """
    return _filterXnor(*filters)



def filterXor(*filters):
    """
    Create a filter that combines all results or values of ``*filters`` using xor-logic.

    Args:
        *filters (tuple): a tuple of filters.

    Returns:
        callable: a filter that xors all elements in ``*filters``.

    Usage::

        >>> filterXor(filter1, filter2, ..., filterN)
        # If an odd number of filters return True, True is returned
        # Exception are rated as a filter returning False
    """
    return _filterXor(*filters)



