# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf._main import TestCompleter as _TestCompleter
from htf._main import dryrun as _dryrun
from htf._main import get_choices as _get_choices
from htf._main import get_tags as _get_tags
from htf._main import main as _main
from htf._main import module_list as _module_list
from htf._main import run as _run


def TestCompleter(**kwargs):
    return _TestCompleter(**kwargs)


def dryrun(title='Testreport',
           tests='__main__',
           tags=None,
           html_report=None,
           junit_xml_report=None,
           json_report=None,
           yaml_report=None,
           report_server=None,
           extra_report=None,
           pattern='test*.py',
           metadata=None,
           exit=True,
           verbosity=1,
           failfast=None,
           catchbreak=None,
           minimize_report_size=False):
    """
    Test runner for a dry run to watch the test suite.

    Args:
        title (str): the test's title
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier ora list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None (str): tags filter expression
        html_report=None (str or list of str): HTML-report filename(s)
        junit_xml_report=None (str or list of str): JUnit-XML-report
            filename(s)
        json_report=None (str or list of str): JSON-report
            filename(s)
        yaml_report=None (str or list of str): YAML-report
            filename(s)
        report_server=None (url or list of urls): Url or list of urls to report server
        extra_report=None (instance or list of instances): Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders
        metadata=None (dict): a dictionary that contains metadata about the test run
        exit=True (bool): if set to ``True`` the exit() is called at the
            end of the tests
        verbosity=1 (int): the verbosity level (the higher the level the
            more verbose is the output)
        failfast=None (bool): if set to ``True`` the test run ends after
            the first failing test
        catchbreak=None (bool): if set to ``True`` CTRL-C is catched wile
            tests run. If CTRL-C is pressed the test run is stopped after
            the current test.
        minimize_report_size=False (bool): if set to ``True`` the report size is minimized.

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _dryrun(title=title,
                   tests=tests,
                   tags=tags,
                   html_report=html_report,
                   junit_xml_report=junit_xml_report,
                   json_report=json_report,
                   yaml_report=yaml_report,
                   report_server=report_server,
                   extra_report=extra_report,
                   pattern=pattern,
                   metadata=metadata,
                   exit=exit,
                   verbosity=verbosity,
                   failfast=failfast,
                   catchbreak=catchbreak,
                   minimize_report_size=minimize_report_size)


def get_choices(part):
    """
    Return a list of strings
    that describe importable python
    modules and its contents.
    Eg.:
    - tests.test_1
    - tests
    - tests.test_1.TestCase
    - tests.test_1.TestCase.test_method

    Case 1) complete or incomplete root module -> list all root
        modules starting with part
    Case 2) complete root module + "." -> list all sub-modules and entries
    Case 3) complete root module + ".<part>" -> list all sub-modules
        and entries starting with part and
    """
    return _get_choices(part=part)


def get_tags(tests='__main__', pattern='test*.py'):
    """
    Get a list of tags found in the specified tests.

    Args:
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier ora list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders

    Returns:
        list of str: a list of tags found in the specified tests.
    """
    return _get_tags(tests=tests, pattern=pattern)


def main(title='Testreport',
         tests='__main__',
         tags=None,
         html_report=None,
         junit_xml_report=None,
         json_report=None,
         yaml_report=None,
         report_server=None,
         extra_report=None,
         pattern='test*.py',
         metadata=None,
         exit=True,
         verbosity=1,
         failfast=None,
         catchbreak=None,
         minimize_report_size=False):
    """
    Test runner.

    Args:
        title (str): the test's title
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier ora list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None (str): tags filter expression
        html_report=None (str or list of str): HTML-report filename(s)
        junit_xml_report=None (str or list of str): JUnit-XML-report
            filename(s)
        json_report=None (str or list of str): JSON-report
            filename(s)
        yaml_report=None (str or list of str): YAML-report
            filename(s)
        report_server=None (url or list of urls): Url or list of urls to report server
        extra_report=None (instance or list of instances): Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders
        metadata=None (dict): a dictionary that contains metadata about the test run
        exit=True (bool): if set to ``True`` the exit() is called at the
            end of the tests
        verbosity=1 (int): the verbosity level (the higher the level the
            more verbose is the output)
        failfast=None (bool): if set to ``True`` the test run ends after
            the first failing test
        catchbreak=None (bool): if set to ``True`` CTRL-C is catched wile
            tests run. If CTRL-C is pressed the test run is stopped after
            the current test.
        minimize_report_size=False (bool): if set to ``True`` the report size is minimized.

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _main(title=title,
                 tests=tests,
                 tags=tags,
                 html_report=html_report,
                 junit_xml_report=junit_xml_report,
                 json_report=json_report,
                 yaml_report=yaml_report,
                 report_server=report_server,
                 extra_report=extra_report,
                 pattern=pattern,
                 metadata=metadata,
                 exit=exit,
                 verbosity=verbosity,
                 failfast=failfast,
                 catchbreak=catchbreak,
                 minimize_report_size=minimize_report_size)



def module_list(path):
    """
    Return the list containing the names of the modules available in the given
    folder.
    """
    return _module_list(path=path)



def run(title='Testreport',
        tests='__main__',
        tags=None,
        html_report=None,
        junit_xml_report=None,
        json_report=None,
        yaml_report=None,
        report_server=None,
        extra_report=None,
        pattern='test*.py',
        metadata=None,
        exit=True,
        verbosity=1,
        failfast=None,
        catchbreak=None,
        minimize_report_size=False):
    """
    Test runner.

    Args:
        title (str): the test's title
        tests=None (test-specifier or list of test-specifiers): a
            test-specifier ora list of test-specifiers
            (folder, file, test-case, test-case-method, module)
        tags=None (str): tags filter expression
        html_report=None (str or list of str): HTML-report filename(s)
        junit_xml_report=None (str or list of str): JUnit-XML-report
            filename(s)
        json_report=None (str or list of str): JSON-report
            filename(s)
        yaml_report=None (str or list of str): YAML-report
            filename(s)
        report_server=None (url or list of urls): Url or list of urls to report server
        extra_report=None (instance or list of instances): Extra reports
            that support instance.render(data). This is useful for
            :class:`htf.DOORSTestReport` for example that needs
            additional parameters.
        pattern="test*.py" (str): the pattern to be used when searching for
            python files in folders
        metadata=None (dict): a dictionary that contains metadata about the test run
        exit=True (bool): if set to ``True`` the exit() is called at the
            end of the tests
        verbosity=1 (int): the verbosity level (the higher the level the
            more verbose is the output)
        failfast=None (bool): if set to ``True`` the test run ends after
            the first failing test
        catchbreak=None (bool): if set to ``True`` CTRL-C is catched wile
            tests run. If CTRL-C is pressed the test run is stopped after
            the current test.
        minimize_report_size=False (bool): if set to ``True`` the report size is minimized.

    Returns:
        int: ``0`` if the run was successful or the number of failed tests in case or errors and failures.
    """
    return _run(title=title,
                tests=tests,
                tags=tags,
                html_report=html_report,
                junit_xml_report=junit_xml_report,
                json_report=json_report,
                yaml_report=yaml_report,
                report_server=report_server,
                extra_report=extra_report,
                pattern=pattern,
                metadata=metadata,
                exit=exit,
                verbosity=verbosity,
                failfast=failfast,
                catchbreak=catchbreak,
                minimize_report_size=minimize_report_size)
