# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.powersupply._manson_hcs_3xxx import MansonHCS3xxx as _MansonHCS3xxx
from htf.powersupply._manson_hcs_3xxx import TimeoutException as _TimeoutException


class MansonHCS3xxx(_MansonHCS3xxx):
    """
    ``MansonHCS3xxx`` is a hardware abstraction to the Manson HCS-3xxx power supply family using a UART to control it.

    ``MansonHCS3xxx`` uses ``DelegatorMixin`` to automatically set and read it's members `voltage` and `current`.
    """

    def __init__(self, port, decimalPlacesForCurrent=1, debug=False):
        """
        Args:
            port (str): the comport to be used, eg. "COM3", 3 or "/dev/ttyUSB0", etc.
            decimalPlacesForCurrent=1 (int): the number of decimal places for the current.
                HCS-3100, 3150, 3200 and 3202 have one decimal place. HCS-3102, 3014 and 3204 have two decimal places.
            debug=False (bool): if set to `True` debugging is enabled
        """
        super(MansonHCS3xxx, self).__init__(port=port, decimalPlacesForCurrent=decimalPlacesForCurrent, debug=debug)

    def close(self):
        """
        Close the serial member. This method is automatically called when :func:`__del__` is called.
        """
        return super(MansonHCS3xxx, self).close()

    def disableOutput(self):
        """
        Disable output.
        """
        return super(MansonHCS3xxx, self).disableOutput()

    def enableOutput(self):
        """
        Enable output.
        """
        return super(MansonHCS3xxx, self).enableOutput()

    def getCurrent(self):
        """
        Read the current current from device and return the result.

        Returns:
            float: the current current.
        """
        return super(MansonHCS3xxx, self).getCurrent()

    def getDisplayVoltageCurrentAndStatus(self):
        """
        Get the display voltage, current and status.

        Returns:
            dict: a dictionary containing "voltage", "current" and "status".
        """
        return super(MansonHCS3xxx, self).getDisplayVoltageCurrentAndStatus()

    def getPresetMaximumCurrent(self):
        """
        Get preset maximum current for current preset.

        Returns:
            int: the preset maximum current.
        """
        return super(MansonHCS3xxx, self).getPresetMaximumCurrent()

    def getPresetMaximumVoltage(self):
        """
        Get preset maximum voltage for current preset.

        Returns:
            int: the preset maximum voltage.
        """
        return super(MansonHCS3xxx, self).getPresetMaximumVoltage()

    def getPresetMaximumVoltageAndCurrent(self):
        """
        Get the preset maximum voltage and current.

        Returns:
            dict: a dictionary containing "voltage" and "current".
        """
        return super(MansonHCS3xxx, self).getPresetMaximumVoltageAndCurrent()

    def getPresetVoltageAndCurrent(self):
        """
        Get the preset voltage and current.

        Returns:
            dict: a dictionary containing "voltage" and "current".
        """
        return super(MansonHCS3xxx, self).getPresetVoltageAndCurrent()

    def getPresets(self):
        """
        Get three voltage-current presets.

        Returns:
            dict: a dictionary containing "voltage", "current" and "P<preset>".
        """
        return super(MansonHCS3xxx, self).getPresets()

    def getVoltage(self):
        """
        Read current voltage from device and return the result.

        Returns:
            float: the current voltage.
        """
        return super(MansonHCS3xxx, self).getVoltage()

    def loadPreset(self, preset):
        """
        Load preset ``preset``.

        Args:
            preset (int): may be 0, 1, or 2.
        """
        return super(MansonHCS3xxx, self).loadPreset(preset=preset)

    def presetMaximumCurrent(self, current):
        """
        Set maximum voltage for current preset.
        """
        return super(MansonHCS3xxx, self).presetMaximumCurrent(current=current)

    def presetMaximumVoltage(self, voltage):
        """
        Set maximum voltage for current preset.
        """
        return super(MansonHCS3xxx, self).presetMaximumVoltage(voltage=voltage)

    def query(self, query, answerLines=1):
        """
        Send a command and wait for the answer.

        Args:
            query (str): the query to be sent.
            answerLines=1 (int): the number of lines to be received.

        Returns:
            str: the answer line(s).

        Raises:
            manson_hcs_3xxx.TimeoutException: if a communication time-out occurred.
        """
        return super(MansonHCS3xxx, self).query(query=query, answerLines=answerLines)

    def setCurrent(self, current):
        """
        Set the output current to ``current``.

        Args:
            current (int, float or str): the current in units of amperes as int(), float() or string, eg. 0, 0.5,
             "0.5" or even "0.5 mA" work.
        """
        return super(MansonHCS3xxx, self).setCurrent(current=current)

    def setVoltage(self, voltage):
        """
        Set the output voltage to ``voltage``.

        Args:
            voltage (int, float or str): the voltage in units of volts as int(), float() or string, eg. 23, 23.0,
                "23.0" or even "23.0 V" work.
                `voltage` may have on decimal point. If `voltage` is ``None`` the output is disabled.
        """
        return super(MansonHCS3xxx, self).setVoltage(voltage=voltage)

    def storePresets(self, presets):
        """
        Store three voltage-current presets.

        Args:
            presets (dict): a dictionary containing the key P1, P2 and P3. Each key constaint "voltage" and
             "current" keys.

        Usage::

            >>> presets = {
            >>>    'P1': {'current': 12.0, 'voltage': 5.0},
            >>>    'P2': {'current': 12.0, 'voltage': 13.8},
            >>>    'P3': {'current': 12.0, 'voltage': 25.0}}
            >>> manson.storePresets(presets)
        """
        return super(MansonHCS3xxx, self).storePresets(presets=presets)



class TimeoutException(_TimeoutException):
    """
    Exception that is raised if a communication time-out occurred.
    """

