# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#

from __future__ import \
    absolute_import, division, print_function, unicode_literals


import sys


def init_termcolors():
    if sys.platform not in {'win32', 'cli'}:
        return

    import colorama
    colorama.init()


from .styles import *

init_termcolors()


def info(text):
    """
    Return colored text if supported by terminal using ANSI codes for an information.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return bold(text)


def system(text):
    """
    Return colored text if supported by terminal using ANSI codes for system message.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return blue_bold(text)


def success(text):
    """
    Return colored text if supported by terminal using ANSI codes for a success.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return green_bold(text)


def warning(text):
    """
    Return colored text if supported by terminal using ANSI codes for a failure.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return yellow_bold(text)


def failure(text):
    """
    Return colored text if supported by terminal using ANSI codes for a failure.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return yellow_bold(text)


def error(text):
    """
    Return colored text if supported by terminal using ANSI codes for an error.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return red_bold(text)


def debug(text):
    """
    Return colored text if supported by terminal using ANSI codes for a critical error.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return red_bold(text)


def critical(text):
    """
    Return colored text if supported by terminal using ANSI codes for a critical error.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return yellow_on_red_bold(text)


def skipped(text):
    """
    Return colored text if supported by terminal using ANSI codes for something skipped.

    Args:
        text (str): the text to be colored.

    Returns:
        str: ``text`` colored if supported by the terminal.

    """
    return grey_bold(text)



__all__ = ["info", "system", "success", "warning", "failure", "error", "debug", "critical", "skipped", "demo"] \
          + [func for func in dir(styles)]
