# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#

from __future__ import \
    absolute_import, division, print_function, unicode_literals

import termcolor
import os
import sys


def supports_color():
    """
    Return ``True`` if the running system's terminal supports color and colors are wanted,
    and ``False`` otherwise.
    """

    if "HTF_NO_COLORS" in os.environ:
        # Colors are disabled by environment variable
        return False

    if 'PYCHARM_HOSTED' in os.environ.keys():
        # PyCharm supports colors
        return True

    supported_platform = sys.platform in [
        'linux',
        'linux2',
        'win32',
        'cygwin',
        'darwin',
    ]

    is_a_tty = hasattr(sys.stdout, 'isatty') and sys.stdout.isatty()

    return supported_platform and is_a_tty


# instead of cache
color_is_supported = supports_color()


def make_style(color=None, on_color=None, attrs=None):
    """
    Return a callable that has a parameter text that will be colord
    according to the parameters if coloring is supported.

    Args:
        color=None (str): the color for the text
        on_color=None (str): the backgrond color
        attrs=None (list of str): a list of attributes
    """

    if color_is_supported is True:
        return lambda text: termcolor.colored(text=text, color=color, on_color=on_color, attrs=attrs)
    else:
        return lambda text: text
