# -*- coding: utf-8 -*-
#
# Copyright (c) 2019, HILSTER GmbH, Germany - https://hilster.de
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.core import TestCase as _TestCase


class TestCase(_TestCase):
    """
    ``TestCase`` is the basic test case class for the HILSTER Testing Framework
    that should be used using inheritance.
    """

    def __init__(self, methodName='runTest'):
        """
        Args:
            methodName='runTest' (str): the name of the test method to be
                run by the test runner.
        """
        super(TestCase, self).__init__(methodName=methodName)

    def addCleanup(self, function, *args, **kwargs):
        """
        Add a function, with arguments, to be called when the test is
        completed. Functions added are called on a LIFO basis and are
        called after tearDown on test failure or success.

        Cleanup items are called even if setUp fails (unlike tearDown).
        """
        return super(TestCase, self).addCleanup(function, *args, **kwargs)

    def addTypeEqualityFunc(self, typeobj, function):
        """
        Add a type specific assertEqual style function to compare a type.

        This method is for use by TestCase subclasses that need to register
        their own type equality functions to provide nicer error messages.

        Args:
            typeobj: The data type to call this function on when both values
                    are of the same type in assertEqual().
            function: The callable taking two arguments and an optional
                    msg= argument that raises self.failureException with a
                    useful error message when the two arguments are not equal.
        """
        return super(TestCase, self).addTypeEqualityFunc(typeobj=typeobj, function=function)

    def afterTest(self):
        """
        This method is called after a test ends and before
        :py:func:`htf.unittest.testcase.TestCase.tearDown` is called.
        This method is injected using the :py:func:`htf.decorators.after`
        decorator to be run in the test context.

        If you override this method, make sure to call the original
        implementation::

            class SpecializedTestCase(TestCase):

                def afterTest(self):
                    # your code goes here
                    super(TestCase, self).afterTest()
        """
        return super(TestCase, self).afterTest()

    def assertAlmostEqual(self, first, second, places=None, msg=None, delta=None):
        """
        Fail if the two objects are unequal as determined by their
        difference rounded to the given number of decimal places
        (default 7) and comparing to zero, or by comparing that the
        difference between the two objects is more than the given
        delta.

        Note that decimal places (from zero) are usually not the same
        as significant digits (measured from the most significant digit).

        If the two objects compare equal then they will automatically
        compare almost equal.
        """
        return super(TestCase, self).assertAlmostEqual(first=first, second=second, places=places, msg=msg, delta=delta)

    def assertCountEqual(self, first, second, msg=None):
        """
        An unordered sequence comparison asserting that the same elements,
        regardless of order.  If the same element occurs more than once,
        it verifies that the elements occur the same number of times.

            self.assertEqual(Counter(list(first)),
                             Counter(list(second)))

         Example:
            - [0, 1, 1] and [1, 0, 1] compare equal.
            - [0, 0, 1] and [0, 1] compare unequal.
        """
        return super(TestCase, self).assertCountEqual(first=first, second=second, msg=msg)

    def assertDictEqual(self, d1, d2, msg=None):
        return super(TestCase, self).assertDictEqual(d1=d1, d2=d2, msg=msg)

    def assertEqual(self, first, second, msg=None):
        """
        Fail if the two objects are unequal as determined by the '=='
        operator.
        """
        return super(TestCase, self).assertEqual(first=first, second=second, msg=msg)

    def assertFalse(self, expr, msg=None):
        """
        Check that the expression is false.
        """
        return super(TestCase, self).assertFalse(expr=expr, msg=msg)

    def assertGreater(self, a, b, msg=None):
        """
        Just like self.assertTrue(a > b), but with a nicer default message.
        """
        return super(TestCase, self).assertGreater(a=a, b=b, msg=msg)

    def assertGreaterEqual(self, a, b, msg=None):
        """
        Just like self.assertTrue(a >= b), but with a nicer default message.
        """
        return super(TestCase, self).assertGreaterEqual(a=a, b=b, msg=msg)

    def assertIn(self, member, container, msg=None):
        """
        Just like self.assertTrue(a in b), but with a nicer default message.
        """
        return super(TestCase, self).assertIn(member=member, container=container, msg=msg)

    def assertIs(self, expr1, expr2, msg=None):
        """
        Just like self.assertTrue(a is b), but with a nicer default message.
        """
        return super(TestCase, self).assertIs(expr1=expr1, expr2=expr2, msg=msg)

    def assertIsInstance(self, obj, cls, msg=None):
        """
        Same as self.assertTrue(isinstance(obj, cls)), with a nicer
        default message.
        """
        return super(TestCase, self).assertIsInstance(obj=obj, cls=cls, msg=msg)

    def assertIsNone(self, obj, msg=None):
        """
        Same as self.assertTrue(obj is None), with a nicer default message.
        """
        return super(TestCase, self).assertIsNone(obj=obj, msg=msg)

    def assertIsNot(self, expr1, expr2, msg=None):
        """
        Just like self.assertTrue(a is not b), but with a nicer default message.
        """
        return super(TestCase, self).assertIsNot(expr1=expr1, expr2=expr2, msg=msg)

    def assertIsNotNone(self, obj, msg=None):
        """
        Included for symmetry with assertIsNone.
        """
        return super(TestCase, self).assertIsNotNone(obj=obj, msg=msg)

    def assertLess(self, a, b, msg=None):
        """
        Just like self.assertTrue(a < b), but with a nicer default message.
        """
        return super(TestCase, self).assertLess(a=a, b=b, msg=msg)

    def assertLessEqual(self, a, b, msg=None):
        """
        Just like self.assertTrue(a <= b), but with a nicer default message.
        """
        return super(TestCase, self).assertLessEqual(a=a, b=b, msg=msg)

    def assertListEqual(self, list1, list2, msg=None):
        """
        A list-specific equality assertion.

        Args:
            list1: The first list to compare.
            list2: The second list to compare.
            msg: Optional message to use on failure instead of a list of
                    differences.
        """
        return super(TestCase, self).assertListEqual(list1=list1, list2=list2, msg=msg)

    def assertLogs(self, logger=None, level=None):
        """
        Fail unless a log message of level *level* or higher is emitted
        on *logger_name* or its children.  If omitted, *level* defaults to
        INFO and *logger* defaults to the root logger.

        This method must be used as a context manager, and will yield
        a recording object with two attributes: `output` and `records`.
        At the end of the context manager, the `output` attribute will
        be a list of the matching formatted log messages and the
        `records` attribute will be a list of the corresponding LogRecord
        objects.

        Example::

            with self.assertLogs('foo', level='INFO') as cm:
                logging.getLogger('foo').info('first message')
                logging.getLogger('foo.bar').error('second message')
            self.assertEqual(cm.output, ['INFO:foo:first message',
                                         'ERROR:foo.bar:second message'])
        """
        return super(TestCase, self).assertLogs(logger=logger, level=level)

    def assertMultiLineEqual(self, first, second, msg=None):
        """
        Assert that two multi-line strings are equal.
        """
        return super(TestCase, self).assertMultiLineEqual(first=first, second=second, msg=msg)

    def assertNotAlmostEqual(self, first, second, places=None, msg=None, delta=None):
        """
        Fail if the two objects are equal as determined by their
        difference rounded to the given number of decimal places
        (default 7) and comparing to zero, or by comparing that the
        difference between the two objects is less than the given delta.

        Note that decimal places (from zero) are usually not the same
        as significant digits (measured from the most significant digit).

        Objects that are equal automatically fail.
        """
        return super(TestCase, self).assertNotAlmostEqual(first=first, second=second, places=places, msg=msg, delta=delta)

    def assertNotEqual(self, first, second, msg=None):
        """
        Fail if the two objects are equal as determined by the '!='
        operator.
        """
        return super(TestCase, self).assertNotEqual(first=first, second=second, msg=msg)

    def assertNotEquals(*args, **kwargs):
        return super(TestCase, self).assertNotEquals(*args, **kwargs)

    def assertNotIn(self, member, container, msg=None):
        """
        Just like self.assertTrue(a not in b), but with a nicer default message.
        """
        return super(TestCase, self).assertNotIn(member=member, container=container, msg=msg)

    def assertNotIsInstance(self, obj, cls, msg=None):
        """
        Included for symmetry with assertIsInstance.
        """
        return super(TestCase, self).assertNotIsInstance(obj=obj, cls=cls, msg=msg)

    def assertNotRegex(self, text, unexpected_regex, msg=None):
        """
        Fail the test if the text matches the regular expression.
        """
        return super(TestCase, self).assertNotRegex(text=text, unexpected_regex=unexpected_regex, msg=msg)

    def assertRaises(self, expected_exception, *args, **kwargs):
        """
        Fail unless an exception of class expected_exception is raised
        by the callable when invoked with specified positional and
        keyword arguments. If a different type of exception is
        raised, it will not be caught, and the test case will be
        deemed to have suffered an error, exactly as for an
        unexpected exception.

        If called with the callable and arguments omitted, will return a
        context object used like this::

             with self.assertRaises(SomeException):
                 do_something()

        An optional keyword argument 'msg' can be provided when assertRaises
        is used as a context object.

        The context manager keeps a reference to the exception as
        the 'exception' attribute. This allows you to inspect the
        exception after the assertion::

            with self.assertRaises(SomeException) as cm:
                do_something()
            the_exception = cm.exception
            self.assertEqual(the_exception.error_code, 3)
        """
        return super(TestCase, self).assertRaises(expected_exception, *args, **kwargs)

    def assertRaisesRegex(self, expected_exception, expected_regex, *args, **kwargs):
        """
        Asserts that the message in a raised exception matches a regex.

        Args:
            expected_exception: Exception class expected to be raised.
            expected_regex: Regex (re pattern object or string) expected
                    to be found in error message.
            args: Function to be called and extra positional args.
            kwargs: Extra kwargs.
            msg: Optional message used in case of failure. Can only be used
                    when assertRaisesRegex is used as a context manager.
        """
        return super(TestCase, self).assertRaisesRegex(expected_exception, expected_regex, *args, **kwargs)

    def assertRegex(self, text, expected_regex, msg=None):
        """
        Fail the test unless the text matches the regular expression.
        """
        return super(TestCase, self).assertRegex(text=text, expected_regex=expected_regex, msg=msg)

    def assertSequenceEqual(self, seq1, seq2, msg=None, seq_type=None):
        """
        An equality assertion for ordered sequences (like lists and tuples).

        For the purposes of this function, a valid ordered sequence type is one
        which can be indexed, has a length, and has an equality operator.

        Args:
            seq1: The first sequence to compare.
            seq2: The second sequence to compare.
            seq_type: The expected datatype of the sequences, or None if no
                    datatype should be enforced.
            msg: Optional message to use on failure instead of a list of
                    differences.
        """
        return super(TestCase, self).assertSequenceEqual(seq1=seq1, seq2=seq2, msg=msg, seq_type=seq_type)

    def assertSetEqual(self, set1, set2, msg=None):
        """
        A set-specific equality assertion.

        Args:
            set1: The first set to compare.
            set2: The second set to compare.
            msg: Optional message to use on failure instead of a list of
                    differences.

        assertSetEqual uses ducktyping to support different types of sets, and
        is optimized for sets specifically (parameters must support a
        difference method).
        """
        return super(TestCase, self).assertSetEqual(set1=set1, set2=set2, msg=msg)

    def assertTrue(self, expr, msg=None):
        """
        Check that the expression is true.
        """
        return super(TestCase, self).assertTrue(expr=expr, msg=msg)

    def assertTupleEqual(self, tuple1, tuple2, msg=None):
        """
        A tuple-specific equality assertion.

        Args:
            tuple1: The first tuple to compare.
            tuple2: The second tuple to compare.
            msg: Optional message to use on failure instead of a list of
                    differences.
        """
        return super(TestCase, self).assertTupleEqual(tuple1=tuple1, tuple2=tuple2, msg=msg)

    def assertWarns(self, expected_warning, *args, **kwargs):
        """
        Fail unless a warning of class warnClass is triggered
        by the callable when invoked with specified positional and
        keyword arguments.  If a different type of warning is
        triggered, it will not be handled: depending on the other
        warning filtering rules in effect, it might be silenced, printed
        out, or raised as an exception.

        If called with the callable and arguments omitted, will return a
        context object used like this::

             with self.assertWarns(SomeWarning):
                 do_something()

        An optional keyword argument 'msg' can be provided when assertWarns
        is used as a context object.

        The context manager keeps a reference to the first matching
        warning as the 'warning' attribute; similarly, the 'filename'
        and 'lineno' attributes give you information about the line
        of Python code from which the warning was triggered.
        This allows you to inspect the warning after the assertion::

            with self.assertWarns(SomeWarning) as cm:
                do_something()
            the_warning = cm.warning
            self.assertEqual(the_warning.some_attribute, 147)
        """
        return super(TestCase, self).assertWarns(expected_warning, *args, **kwargs)

    def assertWarnsRegex(self, expected_warning, expected_regex, *args, **kwargs):
        """
        Asserts that the message in a triggered warning matches a regexp.
        Basic functioning is similar to assertWarns() with the addition
        that only warnings whose messages also match the regular expression
        are considered successful matches.

        Args:
            expected_warning: Warning class expected to be triggered.
            expected_regex: Regex (re pattern object or string) expected
                    to be found in error message.
            args: Function to be called and extra positional args.
            kwargs: Extra kwargs.
            msg: Optional message used in case of failure. Can only be used
                    when assertWarnsRegex is used as a context manager.
        """
        return super(TestCase, self).assertWarnsRegex(expected_warning, expected_regex, *args, **kwargs)

    def attachFile(self, filename, title):
        """
        Attach a file to the current test that is put into
        the test report.

        The attachment size is checked using
        :py:func:`htf.TestCase.get_maximum_attachment_size`.

        Args:
            filename (str): the filename to be attached
            title (str): the title
        """
        return super(TestCase, self).attachFile(filename=filename, title=title)

    def attachUrl(self, url, title):
        """
        Attach an url to the current test that is put into the test report.
        This results in an external link and should be used for huge files.

        Args:
            url (str): the url to be attached
            title (str): the title
        """
        return super(TestCase, self).attachUrl(url=url, title=title)

    def attach_file(self, filename, title):
        """
        Attach a file to the current test that is put into
        the test report.

        The attachment size is checked using
        :py:func:`htf.TestCase.get_maximum_attachment_size`.

        Args:
            filename (str): the filename to be attached
            title (str): the title
        """
        return super(TestCase, self).attach_file(filename=filename, title=title)

    def attach_url(self, url, title):
        """
        Attach an url to the current test that is put into the test report.
        This results in an external link and should be used for huge files.

        Args:
            url (str): the url to be attached
            title (str): the title
        """
        return super(TestCase, self).attach_url(url=url, title=title)

    def countTestCases(self):
        return super(TestCase, self).countTestCases()

    def debug(self):
        """
        Run the test without collecting errors in a TestResult
        """
        return super(TestCase, self).debug()

    def defaultTestResult(self):
        return super(TestCase, self).defaultTestResult()

    def doCleanups(self):
        """
        Execute all cleanup functions. Normally called for you after
        tearDown.
        """
        return super(TestCase, self).doCleanups()

    def expect(self, expectedValue, observedValue, errorMessage=None):
        """
        Expect that ``expectedValue`` and ``observedValue`` are the same.
        If ``expectedValue`` and ``observedValue`` differ an ``AssertionError``
        is raised.

        Args:
            expectedValue: the expected value.
            observedValue: the observed value that is compared to
                ``expectedValue``.
            errorMessage=None (str): an optional message.
        """
        return super(TestCase, self).expect(expectedValue=expectedValue, observedValue=observedValue, errorMessage=errorMessage)

    def expectStep(self, title, expectedValue, observedValue, errorMessage=None):
        """
        Creates a test step in test report and on stdout using ``title``.
        Expect that `expectedValue` and `observedValue` are the same.
        If ``expectedValue`` and ``observedValue`` differ an ``AssertionError``
        is raised.

        Args:
            title (str): the step's title.
            expectedValue: the value that is expected.
            observedValue: the current observed value that is compared to
                ``expectedValue``.
            errorMessage=None (str): an optional message.
        """
        return super(TestCase, self).expectStep(title=title, expectedValue=expectedValue, observedValue=observedValue, errorMessage=errorMessage)

    def fail(self, msg=None):
        """
        Fail immediately, with the given message.
        """
        return super(TestCase, self).fail(msg=msg)

    def failUnlessAlmostEqual(*args, **kwargs):
        return super(TestCase, self).failUnlessAlmostEqual(*args, **kwargs)

    def getData(self):
        return super(TestCase, self).getData()

    def getDoc(self):
        """
        Returns the concatination of test case docs and test method docs.
        """
        return super(TestCase, self).getDoc()

    def getStderr(self):
        return super(TestCase, self).getStderr()

    def getStdout(self):
        return super(TestCase, self).getStdout()

    def getTestCaseDoc(self):
        return super(TestCase, self).getTestCaseDoc()

    def getTestMethodDoc(self):
        return super(TestCase, self).getTestMethodDoc()

    def get_maximum_attachment_size(self):
        """
        Return the maximum attachments size in bytes.

        The default size is 10 Mb.

        Returns:
            int: the maximum attachment size in bytes
        """
        return super(TestCase, self).get_maximum_attachment_size()

    def id(self):
        return super(TestCase, self).id()

    def log(self, *args):
        """
        Log ``*args`` to stdout and into the result of the given step if run in
        a step context block. This method is not thread-safe!

        Args:
            *args (iterable): a tuple of python objects that must be
                convertible into a string.
                All parameters are concatenated with spaces and converted to
                string before.
        """
        return super(TestCase, self).log(*args)

    def run(self, result=None):
        return super(TestCase, self).run(result=result)

    def runBackground(self, func, name=None, joinTimeout=1, args=None, kwargs=None):
        """
        With this method you can run another method in background.

        If this method uses a while loop, it must poll
        ``self._runThreadsEnable`` to be able to be terminated.
        If the background thread does not terminate, the foreground thread
        never ends!

        Args:
            func (callable): the method to be run in background.
            name=None (str): a name for the background task.
                Default: ``None``. If `name` is ``None`` `func.__name__` is
                used.
            joinTimeout=1 (float): the timeout to be used when calling ``join``
                on the thread.
            args=None (tuple): a tuple of positional arguments that are passed
                to the background task when it is called.
            kwargs=None (dict): a dictionary of keyword arguments that are
                passed to the background task when it is called.
        """
        return super(TestCase, self).runBackground(func=func, name=name, joinTimeout=joinTimeout, args=args, kwargs=kwargs)

    def runPeriodic(self, func, period, maximumPeriod=None, name=None, raiseException=True, args=None, kwargs=None):
        """
        With this method you can run another method periodically
        in background with a given period.

        Args:
            func (callable): the method to be called periodically in
                background.
            period (float): the period in second.
            maximumPeriod=None (float): if set to a float >= ``period``
                ``func`` may take up to ``maximumPeriod`` time without
                raising an exception. A warning is printed out to stdout
                instead.
            name=None (str): a name for the background task.
            raiseExceptions=True: if set to ``True`` exceptions are put into
                the exception queue to let a test fail if a background thread
                fails.
            args=None (tuple): a tuple of positional arguments that are passed
                to the background task when it is called.
            kwargs=None (dict): a dictionary of keyword arguments that are
                passed to the background task when it is called.

        Returns:
            stop-trigger (callable): a callable object is returned that stops
                execution when called.
        """
        return super(TestCase, self).runPeriodic(func=func, period=period, maximumPeriod=maximumPeriod, name=name, raiseException=raiseException, args=args, kwargs=kwargs)

    def setMetadata(self, name, value):
        """
        Set metadata for a running test.

        Args:
            name (str): the name of the metadata
            value (str): the value of the metadata
                (``value`` is casted to a string automatically)

        Raises:
            AssertionError: if ``name`` was already set to non accidently overwrite
                existing metdata
        """
        return super(TestCase, self).setMetadata(name=name, value=value)

    def setOutputCaptureEnable(self, enabled=True):
        """
        Enables or disables capturing of stdout and stderr for later
        use in test reports.

        Args:
            enabled=True (bool): the new enabled state
        """
        return super(TestCase, self).setOutputCaptureEnable(enabled=enabled)

    def setUp(self):
        """
        This method is called from test runner before a test is executed to
        create the test-fixtures.

        If you override this method, make sure to call the original
        implementation::

            def setUp(self):
                super(TestCase, self).setUp()
                 # your code goes here
        """
        return super(TestCase, self).setUp()

    @classmethod
    def setUpClass(cls):
        """
        Hook method for setting up class fixture before running tests in the class.
        """
        return super(TestCase, cls).setUpClass()

    def set_metadata(self, name, value):
        """
        Set metadata for a running test.

        Args:
            name (str): the name of the metadata
            value (str): the value of the metadata
                (``value`` is casted to a string automatically)

        Raises:
            AssertionError: if ``name`` was already set to non accidently overwrite
                existing metdata
        """
        return super(TestCase, self).set_metadata(name=name, value=value)

    def shortDescription(self):
        """
        Returns the concatination of test case docs and test method docs.
        """
        return super(TestCase, self).shortDescription()

    def skipStep(self, message):
        """
        Skip the current test step.
        """
        return super(TestCase, self).skipStep(message=message)

    def skipTest(self, message):
        """
        Skip the current test.
        """
        return super(TestCase, self).skipTest(message=message)

    def skip_step(self, message):
        """
        Skip the current test step.
        """
        return super(TestCase, self).skip_step(message=message)

    def skip_test(self, message):
        """
        Skip the current test.
        """
        return super(TestCase, self).skip_test(message=message)

    def step(self, title, callableObj=None, *args, **kwargs):
        """
        Run a test step that is documented in the test report.

        Args:
            title (str): the step's title.
            callableObj=None (callable): a callable object that is called
                within the step or ``None``.
            *args (tuple): a tuple of positional arguments for the step's
                context.
            **kwargs (dict): a dictionary of keyword arguments for the step's
                context.

        Usage:

        .. code-block:: python

            with self.step(title="Description of this test step .."):
                # methodCall()
                self.assertTrue(True "Message in case of an error")

        Or an equivalent approach:

        .. code-block:: python

            self.step(title="Description of this test step comes here ..",
                self.assertTrue, True, "Message in case of an error")
            # method calls are not possible here!
        """
        return super(TestCase, self).step(title, callableObj, *args, **kwargs)

    def stopThread(self, nameOrFunction):
        """
        This method stops a specific thread with the name or
        function described by ``nameOrFunction`` by calling
        :func:`~threading.Thread.join` with join timeout supplied
        by :func:`~htf.TestCase.runPeriodic` or
        :func:`~htf.TestCase.runBackground` or on it.
        It does not set a stop condition so the thread must end and must
        not include an endless loop.
        If the thread is still alive after the first join messages are
        printed to inform the user.

        Args:
            nameOrFunction (str, callable): the name or the function
                (reference) of the thread to be stopped.

        Returns:
            int: the number of stopped threads.

        Raises:
            Exception: if the thread was not found
        """
        return super(TestCase, self).stopThread(nameOrFunction=nameOrFunction)

    def stopThreads(self):
        """
        This method stops all background threads by setting
        ``self._runThreadsEnable`` to ``False`` and calling ``thread.join()``
        until it is not alive anymore.
        """
        return super(TestCase, self).stopThreads()

    def subTest(*args, **kwds):
        """
        Return a context manager that will return the enclosed block
        of code in a subtest identified by the optional message and
        keyword parameters.  A failure in the subtest marks the test
        case as failed but resumes execution at the end of the enclosed
        block, allowing further test code to be executed.
        """
        return super(TestCase, self).subTest(*args, **kwds)

    def tearDown(self):
        """
        This method is called from test runner after a test was executed
        regardless of it's result.

        This method shall destroy all used fixtures.

        If you override this method, make sure to call the original
        implementation::

            def tearDown(self):
                # your code goes here
                super(TestCase, self).tearDown()
        """
        return super(TestCase, self).tearDown()

    @classmethod
    def tearDownClass(cls):
        """
        Hook method for deconstructing the class fixture after running all tests in the class.
        """
        return super(TestCase, cls).tearDownClass()



